Bibo
####

.. image:: https://travis-ci.org/Nagasaki45/bibo.svg?branch=master
    :target: https://travis-ci.org/Nagasaki45/bibo

.. image:: https://codecov.io/gh/Nagasaki45/bibo/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/Nagasaki45/bibo


A reference manager with a single source of truth: the .bib file. Inspired by `beets`_.

.. code-block:: bash

    pip install --user bibo
    bibo --help


.. _beets: https://github.com/beetbox/beets
